use crate::json_util::get_json_object;
use crate::json_util::get_json_string;

pub struct PullRequestEvent<'a> {
    original_event: &'a serde_json::Value,
    pub action: &'a String,
}

impl<'a> PullRequestEvent<'a> {
    pub fn new(original_event: &'a serde_json::Value) -> Result<Self, Box<dyn std::error::Error>> {
        let payload = original_event
            .get("payload")
            .map(get_json_object)
            .expect("Ran into a PullRequestEvent without a payload.");
        let action = payload
            .get("action")
            .map(get_json_string)
            .expect("Ran into a PullRequestEvent without a payload.action.");

        Ok(PullRequestEvent {
            original_event,
            action,
        })
    }

    pub fn is_a(event: &'a serde_json::Value) -> Result<bool, Box<dyn std::error::Error>> {
        let event_type = event.get("type").map(get_json_string);
        match event_type {
            Some(event_type_string) if event_type_string == "PullRequestEvent" => {
                return Ok(true);
            }
            _ => Ok(false),
        }
    }
}
